==> kdesdk-3.3.2.tar.bz2: kdesdk-3.3.2/kbabel/common/kbprojectmanager.cpp <==
/* ****************************************************************************
  This file is part of KBabel

  Copyright (C) 2004 by Stanislav Visnovsky
                            <visnovsky@kde.org>

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

**************************************************************************** */

#include "kbprojectmanager.h"

namespace KBabel
{

QPtrList<Project> ProjectManager::p_list;

Project::Ptr ProjectManager::open( const QString& file )
{
    // TODO: ensure full path
    // TODO: isn't a map better?
    for(QPtrList<Project>::ConstIterator it = p_list.begin();
         it != p_list.end(); ++it)
    {
        if ((*it)->filename() == file)
    	    return (*it);
    }
    
    Project::Ptr f = new Project (file);
    
    p_list.append (f);
    return f;
}

void ProjectManager::close( Project::Ptr project)
{
    // this does nothing, we don't really close projects ATM, just sync the configuration
    project->config()->sync();
}

Project::Ptr ProjectManager::create()
{
    // TODO:
    return 0;
}

void ProjectManager::remove( Project* ref )
{
    p_list.remove (ref);
}

}

==> kdesdk-3.5.0.tar.bz2: kdesdk-3.5.0/kbabel/common/kbprojectmanager.cpp <==
/* ****************************************************************************
  This file is part of KBabel

  Copyright (C) 2004 by Stanislav Visnovsky
                            <visnovsky@kde.org>

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

  In addition, as a special exception, the copyright holders give
  permission to link the code of this program with any edition of
  the Qt library by Trolltech AS, Norway (or with modified versions
  of Qt that use the same license as Qt), and distribute linked
  combinations including the two.  You must obey the GNU General
  Public License in all respects for all of the code used other than
  Qt. If you modify this file, you may extend this exception to
  your version of the file, but you are not obligated to do so.  If
  you do not wish to do so, delete this exception statement from
  your version.

**************************************************************************** */

#include "kbprojectmanager.h"

namespace KBabel
{

QPtrList<Project> ProjectManager::p_list;

Project::Ptr ProjectManager::open( const QString& file )
{
    // TODO: ensure full path
    // TODO: isn't a map better?
    for(QPtrList<Project>::ConstIterator it = p_list.begin();
         it != p_list.end(); ++it)
    {
        if ((*it)->filename() == file)
    	    return (*it);
    }
    
    Project::Ptr f = new Project (file);
    
    if( ! f->valid() )
    {
	return NULL;
    }
    
    p_list.append (f);
    return f;
}

void ProjectManager::close( Project::Ptr project)
{
    // this does nothing, we don't really close projects ATM, just sync the configuration
    project->config()->sync();
}

Project::Ptr ProjectManager::create()
{
    // TODO:
    return 0;
}

void ProjectManager::remove( Project* ref )
{
    p_list.remove (ref);
}

}
